@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthBasic extends SyL_Auth
@@ -57,7 +57,7 @@ class SyL_AuthBasic extends SyL_Auth
         }
         SyL_Response::setHeader('WWW-Authenticate', 'Basic realm="SyL Authentication Area"');
         SyL_Response::setStatusHeader('401');
-        $response =& SyL_Response::getInstance();
+        $response =& SyL_Response::singleton();
         $response->display($view);
 
         trigger_error("[SyL error] Basic Authentication canceled", E_USER_ERROR);
