@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -135,21 +135,22 @@ class SyL_ConfigActions extends SyL_Config
         }
 
         if (!isset($this->config[$this->action_key])) {
-            // б륢¸ߤʤ
+            // б륢ޥåԥ󥰤¸ߤʤ
             trigger_error("[SyL error] Action mapping not found (" . $this->context->getActionFile() . ")", E_USER_ERROR);
         }
 
         // ӥ塼פ򥻥å
         $this->context->setViewType($this->action_cache_value['viewType']);
+        // 쥤̾򥻥å
+        $this->context->setLayoutName($this->action_cache_value['layout']);
+        // ޥӥ塼
+        if ($this->action_cache_value['customizedViewFile'] && $this->action_cache_value['customizedViewClass']) {
+            $this->context->setCustomizedView($this->action_cache_value['customizedViewClass'], $this->action_cache_value['customizedViewFile']);
+        }
 
         if (isset($this->action_cache_value['template'])) {
             $this->context->setTemplateFile($this->action_cache_value['template']);
         }
-        if (isset($this->action_cache_value['view_parameters'])) {
-            foreach ($this->action_cache_value['view_parameters'] as $name => $value) {
-                $this->context->setViewParameter(strtolower($name), $value);
-            }
-        }
     }
 
     /**
@@ -163,11 +164,13 @@ class SyL_ConfigActions extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
-        static $name               = '';
-        static $component_name     = '';
-        static $component_priority = 0;
-        static $method_name        = '';
-        static $load               = false;
+        static $name                = '';
+        static $pre_name            = '';
+        static $post_name           = '';
+        static $component_name      = '';
+        static $method_name         = '';
+        static $prepost_method_name = '';
+        static $load                = false;
 
 //echo $current_path . "<br>";
         // 1ɺѤߤξʹߥå
@@ -205,6 +208,39 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$name]['args'] = array();
                 // ӥ塼
                 $this->action_cache_value['viewType'] = isset($attribute['viewType']) ? $attribute['viewType'] : '';
+                // 쥤
+                $this->action_cache_value['layout'] = isset($attribute['layout']) ? $attribute['layout'] : '';
+                // ޥӥ塼
+                $this->action_cache_value['customizedViewFile']  = isset($attribute['customizedViewFile'])  ? $attribute['customizedViewFile']  : '';
+                $this->action_cache_value['customizedViewClass'] = isset($attribute['customizedViewClass']) ? $attribute['customizedViewClass'] : '';
+
+                // ̥
+                if (isset($attribute['commonPreAction']) && $attribute['commonPreAction']) {
+                    $pre_name = 'commonPreAction';
+                    $this->config[$pre_name]['class']       = $attribute['commonPreAction'];
+                    $this->config[$pre_name]['type']        = 'action';
+                    $this->config[$pre_name]['file']        = SYL_APP_DIR . '/' .  $attribute['commonPreAction'] . '.php';
+                    $this->config[$pre_name]['reference']   = true;
+                    $this->config[$pre_name]['priority']    = $this->default_priority - 1; // ¹Խ(1ʳᤤ)
+                    $this->config[$pre_name]['constructor'] = false;
+                    $this->config[$pre_name]['force']       = false;
+                    $this->config[$pre_name]['event'][$this->event][] = $pre_name;
+                    $this->config[$pre_name]['args'] = array();
+                }
+
+                // ̥
+                if (isset($attribute['commonPostAction']) && $attribute['commonPostAction']) {
+                    $post_name = 'commonPostAction';
+                    $this->config[$post_name]['class']       = $attribute['commonPostAction'];
+                    $this->config[$post_name]['type']        = 'action';
+                    $this->config[$post_name]['file']        = SYL_APP_DIR . '/' .  $attribute['commonPostAction'] . '.php';
+                    $this->config[$post_name]['reference']   = true;
+                    $this->config[$post_name]['priority']    = $this->default_priority + 1; // ¹Խ(1ʳ٤)
+                    $this->config[$post_name]['constructor'] = false;
+                    $this->config[$post_name]['force']       = false;
+                    $this->config[$post_name]['event'][$this->event][] = $post_name;
+                    $this->config[$post_name]['args'] = array();
+                }
 
                 // ǥեȥƥץ졼ȼ
                 if ((SYL_ENV_TYPE == 'web') && isset($attribute['template'])) {
@@ -214,8 +250,6 @@ class SyL_ConfigActions extends SyL_Config
                     }
                     $this->action_cache_value['template'] = $template;
                 }
-                // ӥ塼ѥ᡼å
-                $this->action_cache_value['view_parameters'] = $attribute;
             }
             break;
 
@@ -230,25 +264,40 @@ class SyL_ConfigActions extends SyL_Config
                 } else {
                     $method_name = 'setter:set' . ucfirst($attribute['name']) . ':false';
                 }
+                $prepost_method_name = '';
                 $this->config[$name]['event'][$this->event][] = $method_name;
-                $this->config[$name]['args'][$method_name] = array();
+                $this->config[$name]['args'][$method_name]    = array();
                 break;
 
             case '/syl-actions/action/method':
-                if (!isset($this->config[$name]['args'])) {
-                    $this->config[$name]['args'] = array();
-                }
-                $method_name = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
+                $method_name         = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
+                $prepost_method_name = 'method:' . str_replace('{$action}', '', $attribute['name']);
                 $this->config[$name]['args'][$method_name] = array();
-                // ٥ȥ
-                $this->config[$name]['event'][$this->event][] = $method_name;
+                $this->config[$name]['event'][$this->event][] = $method_name; // ٥ȥ
+                if ($pre_name) {
+                    $this->config[$pre_name]['args'][$prepost_method_name] = array();
+                    $this->config[$pre_name]['event'][$this->event][]      = $prepost_method_name; // ٥ȥ
+                }
+                if ($post_name) {
+                    $this->config[$post_name]['args'][$prepost_method_name] = array();
+                    $this->config[$post_name]['event'][$this->event][]      = $prepost_method_name; // ٥ȥ
+                }
                 break;
 
             case '/syl-actions/action/setter/arg':
             case '/syl-actions/action/method/arg':
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
-                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
+                $arg  = "{$type}:{$ref}:{$text}";
+                $this->config[$name]['args'][$method_name][] = $arg;
+                if ($prepost_method_name) {
+                    if ($pre_name) {
+                        $this->config[$pre_name]['args'][$prepost_method_name][] = $arg;
+                    }
+                    if ($post_name) {
+                        $this->config[$post_name]['args'][$prepost_method_name][] = $arg;
+                    }
+                }
                 break;
 
            case '/syl-actions/action/components/component':
@@ -261,8 +310,8 @@ class SyL_ConfigActions extends SyL_Config
                 $this->config[$component_name]['class']     = isset($attribute['class'])  ? $attribute['class'] : $component_name;
                 $this->config[$component_name]['file']      = $attribute['file'];
                 $this->config[$component_name]['reference'] = (isset($attribute['reference']) && ($attribute['reference'] === 'true'));
-                // ¹Խ(1ʳᤤ)
-                $default_priority = $this->default_priority - 1;
+                // ¹Խ(2ʳᤤ)
+                $default_priority = $this->default_priority - 2;
                 $component_priority = isset($attribute['priority']) ? floatval($default_priority . '.' . $attribute['priority']) : $default_priority;
                 $this->config[$component_name]['priority'] = $component_priority;
                 // 󥹥ȥ饯󥸥ե饰
