@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.8 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.9 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,18 +39,18 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.8 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigLayouts.php,v 1.9 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigLayouts extends SyL_Config
 {
     /**
-     * ե̾
+     * оݥ쥤̾
      * 
      * @access private
      * @var string
      */
-    var $action_file = '';
+    var $layout_name = '';
 
     /**
      * ȥ򥻥å
@@ -62,7 +62,10 @@ class SyL_ConfigLayouts extends SyL_Config
     function setController(&$controller)
     {
         $context =& $controller->container->getComponent('context');
-        $this->action_file = $context->getActionFile();
+        $this->layout_name = $context->getLayoutName();
+        if (!$this->layout_name) {
+            trigger_error("[SyL error] Invalid layout name ({$this->layout_name})", E_USER_ERROR);
+        }
     }
 
     /**
@@ -74,7 +77,7 @@ class SyL_ConfigLayouts extends SyL_Config
     {
         if (SYL_CACHE) {
             // åѤ
-            $key = SYL_APP_DIR . $this->action_file;
+            $key = SYL_APP_DIR . $this->layout_name;
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
@@ -85,6 +88,11 @@ class SyL_ConfigLayouts extends SyL_Config
             // åѤʤ
             parent::parseXml();
         }
+
+        if (!isset($this->config['file'])) {
+            // б쥤ȥޥåԥ󥰤¸ߤʤ
+            trigger_error("[SyL error] Layout mapping not found (Layout name: " . $this->layout_name . ")", E_USER_ERROR);
+        }
     }
 
     /**
@@ -116,14 +124,12 @@ class SyL_ConfigLayouts extends SyL_Config
                 return;
             }
 
-            // ̾ǧ
-            $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
-            if (preg_match('/^' . $reg . '$/', $this->action_file)) {
+            // 쥤̾Ƚ
+            if ($attribute['name'] == $this->layout_name) {
                 $layout = true;
                 $this->config['file']       = $attribute['file'];
                 $this->config['templates']  = array();
-                $this->config['view']       = array();
-                $this->config['includes']   = array();
+                $this->config['content']    = array();
                 $this->config['parameters'] = array();
             }
             break;
@@ -136,12 +142,8 @@ class SyL_ConfigLayouts extends SyL_Config
                $this->config['templates'][$attribute['name']] = $attribute['file'];
                break;
 
-            case '/syl-layouts/layout/view':
-                $this->config['view'][$attribute['name']] = '';
-               break;
-
-            case '/syl-layouts/layout/includes/include':
-               $this->config['includes'][] = $attribute['file'];
+            case '/syl-layouts/layout/content':
+                $this->config['content'] = $attribute['name'];
                break;
 
             case '/syl-layouts/layout/parameters/parameter':
