@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -66,7 +66,7 @@ class SyL_ContextJs extends SyL_Context
     function &getRequest()
     {
         if ($this->request == null) {
-            $this->request =& SyL_Request::getInstance();
+            $this->request =& SyL_Request::singleton();
         }
         return $this->request;
     }
