@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.3 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.3 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
@@ -190,28 +190,6 @@ class SyL_ContextWeb extends SyL_ContextJs
         $this->setParameter('_redirect_url', $url);
     }
 
-    /**
-     * ޥӥ塼饹
-     *
-     * @access public
-     * @return string ޥӥ塼饹
-     */
-    function getCustomizedViewClass()
-    {
-        return $this->view_parameters['customizedviewclass'];
-    }
-
-    /**
-     * ޥӥ塼ե
-     *
-     * @access public
-     * @return string ޥӥ塼ե
-     */
-    function getCustomizedViewFile()
-    {
-        return $this->view_parameters['customizedviewfile'];
-    }
-
     /**
      * ƥץ졼ȥե򥻥å
      * 
