@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,7 +46,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
@@ -60,7 +60,7 @@ class SyL_ControllerCmd extends SyL_Controller
     {
         $config_file = array();
         // Х륳ݡͥե
-        $config_file['components'][] = SYL_WEBAPP_CONFIG_DIR . "/{$this->components_file_name}";
+        $config_file['components'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->components_file_name}";
         // ٥ȼ¹
         $this->raiseEvent('initStream', $config_file);
     }
