@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Xml/Rpc/SyL_XmlRpcServerReader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.3 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataXmlrpc.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataXmlrpc extends SyL_Data
@@ -57,7 +57,7 @@ class SyL_DataXmlrpc extends SyL_Data
     function SyL_DataXmlrpc()
     {
         $xml = null;
-        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
+        if (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'POST')) {
             $xml = file_get_contents('php://input');
         }
 
