@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.18 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.19 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.18 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.19 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -141,7 +141,7 @@ class SyL_ErrorWeb extends SyL_Error
 
         $content_type = 'text/html; charset=' . SYL_ENCODE_INTERNAL;
         SyL_Response::setHeader('Content-Type', $content_type);
-        $response =& SyL_Response::getInstance();
+        $response =& SyL_Response::singleton();
         $response->display($contents);
     }
 
@@ -170,7 +170,7 @@ class SyL_ErrorWeb extends SyL_Error
         $view =& SyL_View::getObject($context);
         $view->render();
 
-        $response =& SyL_Response::getInstance();
+        $response =& SyL_Response::singleton();
         $response->display($view);
     }
 
