@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.11 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestCookie.php,v 1.10 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestCookie.php,v 1.11 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestCookie extends SyL_UtilProperty
@@ -68,25 +68,46 @@ class SyL_RequestCookie extends SyL_UtilProperty
      * @param int åͭ
      * @param string åͭȤѥ
      * @param string åͭʥɥᥤ
-     * @param ing 奢HTTPS³ξˤΤߥåե饰
+     * @param bool 奢HTTPS³ξˤΤߥåե饰
      */
     function set($name, $value, $expire=SYL_COOKIE_EXPIRE, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
     {
         // ñѴ y: ǯm: d: h: i: ʬs: 
         if (preg_match('/^(\d+)([ymdhis])$/', $expire, $match)) {
+            $strtotime_format = '';
             switch ($match[2]) {
-            case 'y': $expire = $match[1] * (strtotime('+1 year') - time());   break;
-            case 'm': $expire = $match[1] * (strtotime('+1 month') - time());  break;
-            case 'd': $expire = $match[1] * (strtotime('+1 day') - time());    break;
-            case 'h': $expire = $match[1] * (strtotime('+1 hour') - time());   break;
-            case 'i': $expire = $match[1] * (strtotime('+1 minute') - time()); break;
-            case 's': $expire = $match[1] * (strtotime('+1 second') - time()); break;
+            case 'y': $strtotime_format = '+1 year';   break;
+            case 'm': $strtotime_format = '+1 month';  break;
+            case 'd': $strtotime_format = '+1 day';    break;
+            case 'h': $strtotime_format = '+1 hour';   break;
+            case 'i': $strtotime_format = '+1 minute'; break;
+            case 's': $strtotime_format = '+1 second'; break;
+            }
+            if ($strtotime_format) {
+                $expire = $match[1] * (strtotime($strtotime_format) - time());
             }
         }
         setcookie($name, $value, $expire, $path, $domain, $secure);
         parent::set($name, $value);
     }
 
+    /**
+     * ʣѥ᡼򥻥å
+     * 
+     * @access public
+     * @param array ץѥƥ
+     * @param int åͭ
+     * @param string åͭȤѥ
+     * @param string åͭʥɥᥤ
+     * @param bool 奢HTTPS³ξˤΤߥåե饰
+     */
+    function sets($values, $expire=SYL_COOKIE_EXPIRE, $path=SYL_COOKIE_PATH, $domain=SYL_COOKIE_DOMAIN, $secure=SYL_COOKIE_SECURE)
+    {
+        foreach ($values as $name => $value) {
+            $this->set($name, $value, $expire, $path, $domain, $secure);
+        }
+    }
+
     /**
      * ѥ᡼
      * 
