@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.16 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.16 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -73,16 +73,16 @@ class SyL_RouterParameter extends SyL_Router
 
         switch (count($pathinfo)) {
         case 0:
-            $this->action_name = '';
-            $this->action_file = '/' . $this->action_file_default;
+            $this->action_method = '';
+            $this->action_file   = '/' . $this->action_file_default;
             break;
         case 1:
-            $this->action_name = array_pop($pathinfo);
-            $this->action_file = '/' . $this->action_file_default;
+            $this->action_method = array_pop($pathinfo);
+            $this->action_file   = '/' . $this->action_file_default;
             break;
         default:
-            $this->action_name =  array_pop($pathinfo);
-            $this->action_file = '/' . implode('/', $pathinfo) . $this->exe_ext;
+            $this->action_method =  array_pop($pathinfo);
+            $this->action_file   = '/' . implode('/', array_map('ucfirst', $pathinfo)) . $this->exe_ext;
             array_pop($pathinfo); // ե̾
             break;
         }
@@ -90,9 +90,9 @@ class SyL_RouterParameter extends SyL_Router
         // 饹ե
         $classname = implode('_', array_map('ucfirst', $pathinfo));
         if ($classname) {
-            $this->action_class = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
+            $this->action_class = $classname . '_' . basename($this->action_file, $this->exe_ext);
         } else {
-            $this->action_class = ucfirst(basename($this->action_file,$this->exe_ext));
+            $this->action_class = basename($this->action_file, $this->exe_ext);
         }
     }
 
