@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.21 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -83,7 +83,7 @@ class SyL_Container
     /**
      * 󥹥ȥ饯
      *
-     * @access public
+     * @access private
      */
     function SyL_Container()
     {
@@ -95,11 +95,12 @@ class SyL_Container
      * @access public
      * return object ƥʥ֥
      */
-    function &getContainer()
+    function &singleton()
     {
         static $singleton;
         if (!is_object($singleton)) {
-            $singleton = new SyL_Container();
+            $classname = __CLASS__;
+            $singleton = new $classname();
         }
         return $singleton;
     }
