@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.23 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.24 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.23 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.24 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -211,7 +211,7 @@ class SyL_Controller
         $this->template_dir = SYL_APP_DIR . '/templates';
 
         // ƥ
-        $this->container =& SyL_Container::getContainer();
+        $this->container =& SyL_Container::singleton();
         $this->container->setComponent(SYL_CONTROLLER_NAME, $this);
 
         // shutdownϥɥ
