@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.22 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.23 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.22 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.23 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -57,7 +57,7 @@ class SyL_Error
      * @access public
      * @var string
      */
-    var $eof = "\r\n";
+    var $eol = "\r\n";
     /**
      * ȥ
      * 
@@ -305,11 +305,11 @@ class SyL_Error
      */
     function getErrorMessageTrace()
     {
-        $error_message = '[' . $this->getErrorType() . '] ' . implode($this->eof, $this->getErrorMessages()) . $this->eof;
+        $error_message = '[' . $this->getErrorType() . '] ' . implode($this->eol, $this->getErrorMessages()) . $this->eol;
         foreach ($this->getTrace() as $values) {
             $error_message .= "[file] "     . $values['file']     . " ";
             $error_message .= "[line] "     . $values['line']     . " ";
-            $error_message .= "[function] " . $values['function'] . $this->eof;
+            $error_message .= "[function] " . $values['function'] . $this->eol;
         }
         return $error_message;
     }
@@ -409,7 +409,7 @@ EOF;
 
             // 顼᡼¹
             include_once SYL_INCLUDE_DIR . '/lib/SyL_Mail.php';
-            $mail =& SyL_Mail::getObject(SYL_MAIL_TYPE);
+            $mail =& SyL_Mail::factory(SYL_MAIL_TYPE);
             $mail->setSubject($error_mail_subject);
             $mail->setFrom(SYL_MAIL_ADMIN_ADDRESS);
             $mail->addTo(SYL_MAIL_ADMIN_ADDRESS);
