@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.15 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.15 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
@@ -94,11 +94,11 @@ class SyL_Request
      * 1̃CX^X̎QƂ擾B
      *
      * 擾@
-     *   $SyL_Request =& SyL_Request::getInstance();
+     *   $SyL_Request =& SyL_Request::singleton();
      *
      * @access public
      */
-    function &getInstance()
+    function &singleton()
     {
         static $singleton;
         if (!is_object($singleton)) {
