@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.21 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.21 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -122,7 +122,7 @@ class SyL_View
             $classname = $context->getCustomizedViewClass();
             $classfile = $context->getCustomizedViewFile();
             if (!is_file($classfile)) {
-                $classfile1 = SYL_WEBAPP_LIB_DIR . "/{$classfile}";
+                $classfile1 = SYL_PROJECT_LIB_DIR . "/{$classfile}";
                 if (!is_file($classfile1)) {
                     trigger_error("[SyL error] Customised View file not found ({$classfile} or {$classfile1})", E_USER_ERROR);
                 }
