@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.5 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.6 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilInfo.php,v 1.5 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilInfo.php,v 1.6 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilInfo
@@ -230,7 +230,7 @@ if (!$display || in_array('SERVER', $display)) {
 if (!$display || in_array('CONTAINER', $display)) {
 ?>
 <h2>CONTAINER</h2>
-<?php $container =& SyL_Container::getContainer(); ?>
+<?php $container =& SyL_Container::singleton(); ?>
 <table border="0" cellpadding="3" width="600" class="sylinfo">
 <tr><th class="sylinfo_h">Name</th><th class="sylinfo_h">Type</th><th class="sylinfo_h">Value</th></tr>
 <?php foreach ($container->getConfig() as $name => $value) { ?>
