@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.12 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -45,10 +45,10 @@ require_once 'SyL_Validation.php';
  * ե९饹
  * 
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.10 2007/04/24 16:49:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.12 2007/05/08 15:55:06 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -67,6 +67,13 @@ class SyL_Form
      * @var array
      */
     var $elements = array();
+    /**
+     * ѥ᡼ؿ
+     *
+     * @access private
+     * @var mixed
+     */
+    var $callback_parameter = null;
     /**
      * ɽ
      *
@@ -119,12 +126,12 @@ class SyL_Form
      * @param string ꥯȥ᥽å
      * @param string ꥯURL
      */
-    function SyL_Form($name="syl_form", $method='POST', $action=null)
+    function SyL_Form($name="syl_form", $action=null, $method='POST')
     {
         $this->setAttribute('name',   $name);
         $this->setAttribute('id',     $name);
         $this->setAttribute('method', strtoupper($method));
-        $this->setAttribute('action', !$action ? $_SERVER['PHP_SELF'] : $action);
+        $this->setAttribute('action', $action ? $action : $_SERVER['PHP_SELF']);
 
         // եॹơ
         $this->results['form']       = '';
@@ -135,6 +142,8 @@ class SyL_Form
         $this->results['error_message'] = array();
         // եǽ
         $this->results['elements'] = array();
+        // ǥեȤΥѥ᡼ؿ
+        $this->callback_parameter = array(&$this, 'getParameter');
     }
 
     /**
@@ -200,6 +209,21 @@ class SyL_Form
         return $this->elements[$element_name];
     }
 
+    /**
+     * ѥ᡼ؿ򥻥å
+     *
+     * @access public
+     * @param mixed ѥ᡼ؿ
+     */
+    function setCallbackParameter($callback_parameter)
+    {
+        if (is_callable($callback_parameter)) {
+            $this->callback_parameter = $callback_parameter;
+        } else {
+            trigger_error("[SyL error] Invalid callback parameter. Not function and method (" . var_export($callback_parameter) . ")", E_USER_ERROR);
+        }
+    }
+
     /**
      * ꥯȤͤ
      *
@@ -300,7 +324,7 @@ class SyL_Form
      * @access public
      * @return array ƤǤ
      */
-    function getValueAll()
+    function getValues()
     {
         $values = array();
         foreach (array_keys($this->elements) as $name) {
