@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.12 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ if (!defined('SYL_ENCODE_INTERNAL')) {
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.12 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Mail
@@ -153,7 +153,7 @@ class SyL_Mail
      * @access public
      * @param string ᡼
      */
-    function &getObject($type='Default')
+    function &factory($type='Default')
     {
         $types = explode(':', $type, 2);
         if (!isset($types[1])) {
