@@ -24,10 +24,10 @@
  *
  * -----------------------------------------------------------------------------
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -40,56 +40,15 @@ require_once 'SyL_XmlRssWriter2_0.php';
 /**
  * RSS 0.91饹
  *
- * С̡ݲ
- *
- * [channel]
- *   copyright
- *   description
- *   language
- *   link
- *   pubDate  <- date
- *   title
- *   category <- (null)
- *
- * [image]
- *   height
- *   link
- *   title
- *   url
- *   width
- *
- * [textInput]
- *   description
- *   link
- *   name
- *   title
- *
- * [item]
- *   description
- *   link
- *   title
- *   author   <- (null)
- *   category <- (null)
- *   date     <- (null)
- *   source   <- (null)
- *
  * @package   SyL
- * @author    k.watanabe <k.watanabe@syl.jp>
+ * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_XmlRssWriter0_91 extends SyL_XmlRssWriter2_0
 {
-    /**
-     * RSSС
-     * 
-     * @access protected
-     * @var string
-     */
-    var $version = '0.91';
-
     /**
      * ͥǤ򥻥åȤ
      * 
@@ -123,6 +82,7 @@ class SyL_XmlRssWriter0_91 extends SyL_XmlRssWriter2_0
             case 'author':
             case 'category':
             case 'date':
+            case 'id':
             case 'source':
                 unset($values[$name]);
                 break;
