@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -67,6 +67,15 @@ class CreateApplication
           'templates' => 0755
         );
 
+        $files = array(
+          'actions.xml'     => 'actions.xml',
+          'defines_app.xml' => 'defines.xml',
+          'filters.xml'     => 'filters.xml',
+          'layouts.xml'     => 'layouts.xml',
+          'CommonPreAction.php'  => 'CommonPreAction.php',
+          'CommonPostAction.php' => 'CommonPostAction.php'
+        );
+
         foreach ($dirs as $dir => $mode) {
             if (!is_dir($app_dir . $dir)) {
                 echo "  creating directory {$app_dir}{$dir}\n"; ob_flush();
@@ -75,32 +84,13 @@ class CreateApplication
             }
         }
 
-        echo "  copying file {$app_dir}actions.xml\n"; ob_flush();
-        if (file_exists("{$project_dir}var/skel-templates/actions.xml")) {
-            copy("{$project_dir}var/skel-templates/actions.xml", "{$app_dir}actions.xml");
-        } else {
-            copy(SYL_PROJECT_DIR . '/var/skel-templates/actions.xml', "{$app_dir}actions.xml");
-        }
-
-        echo "  copying file {$app_dir}defines.xml\n"; ob_flush();
-        if (file_exists("{$project_dir}var/skel-templates/defines_app.xml")) {
-            copy("{$project_dir}var/skel-templates/defines_app.xml", "{$app_dir}defines.xml");
-        } else {
-            copy(SYL_PROJECT_DIR . '/var/skel-templates/defines_app.xml', "{$app_dir}defines.xml");
-        }
-
-        echo "  copying file {$app_dir}filters.xml\n"; ob_flush();
-        if (file_exists("{$project_dir}var/skel-templates/filters.xml")) {
-            copy("{$project_dir}var/skel-templates/filters.xml", "{$app_dir}filters.xml");
-        } else {
-            copy(SYL_PROJECT_DIR . '/var/skel-templates/filters.xml', "{$app_dir}filters.xml");
-        }
-
-        echo "  copying file {$app_dir}layouts.xml\n"; ob_flush();
-        if (file_exists("{$project_dir}var/skel-templates/layouts.xml")) {
-            copy("{$project_dir}var/skel-templates/layouts.xml", "{$app_dir}layouts.xml");
-        } else {
-            copy(SYL_PROJECT_DIR . '/var/skel-templates/layouts.xml', "{$app_dir}layouts.xml");
+        foreach ($files as $file_org => $file_dist) {
+            echo "  copying file {$app_dir}{$file_dist}\n"; ob_flush();
+            if (file_exists("{$project_dir}var/skel-templates/{$file_org}")) {
+                copy("{$project_dir}var/skel-templates/{$file_org}", "{$app_dir}{$file_dist}");
+            } else {
+                copy(SYL_PROJECT_DIR . '/var/skel-templates/{$file_org}', "{$app_dir}{$file_dist}");
+            }
         }
     }
 }
