@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateTemplate.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateTemplate.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateTemplate.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateTemplate.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateTemplate
@@ -54,7 +54,7 @@ class CreateTemplate
      */
     function trigger($project_dir, $app_name, $template_file)
     {
-        $template_dir = "{$project_dir}app/{$app_name}/templates";
+        $template_dir = "{$project_dir}app/{$app_name}/templates/";
         if (!is_dir($template_dir)) {
             if (!mkdir($template_dir, 0755)) {
                 trigger_error("[SyL error] template directory can't create ({$template_dir})", E_USER_ERROR);
@@ -67,17 +67,10 @@ class CreateTemplate
         }
 
         for ($i=0; $i<count($template_file); $i++) {
-            if (!preg_match('/^(\\\\|\/)/', $template_file[$i])) {
-                $template_file[$i] = '/' . $template_file[$i];
+            if (preg_match('/^(\\\\|\/)/', $template_file[$i])) {
+                $template_file[$i] = substr($template_file[$i], 1);
             }
-            $file = substr($template_file[$i], 1);
-            if (substr($file, -5) == '.html') {
-                $file = substr($file, 0, -5);
-            } else {
-                $template_file[$i] .= '.html';
-            }
-
-            $file = $template_dir . $template_file[$i];
+            $file = $template_dir . ucfirst($template_file[$i]) . '.html';
             $tmp = dirname($file) . '/';
             $create_dir = array();
             while (preg_match('/^' . preg_quote($template_dir, '/') . '/', $tmp)) {
